==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/offazure/kotlin/outputs/GetSitesControllerResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.offazure.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * A VmwareSite
 * @property agentDetails Gets or sets the on-premises agent details.
 * @property applianceName Gets or sets the Appliance Name.
 * @property discoverySolutionId Gets or sets the ARM ID of migration hub solution for SDS.
 * @property eTag If eTag is provided in the response body, it may also be provided as a header per the normal etag convention.  Entity tags are used for comparing two or more entities from the same requested resource. HTTP/1.1 uses entity tags in the etag (section 14.19), If-Match (section 14.24), If-None-Match (section 14.26), and If-Range (section 14.27) header fields.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property location The geo-location where the resource lives
 * @property masterSiteId Gets the Master Site this site is linked to.
 * @property name The name of the resource
 * @property provisioningState The status of the last operation.
 * @property serviceEndpoint Gets the service endpoint.
 * @property servicePrincipalIdentityDetails Gets or sets the service principal identity details used by agent for
 * communication
 *             to the service.
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property tags Resource tags.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetSitesControllerResult(
    public val agentDetails: SiteAgentPropertiesResponse? = null,
    public val applianceName: String? = null,
    public val discoverySolutionId: String? = null,
    public val eTag: String,
    public val id: String,
    public val location: String,
    public val masterSiteId: String,
    public val name: String,
    public val provisioningState: String,
    public val serviceEndpoint: String,
    public val servicePrincipalIdentityDetails: SiteSpnPropertiesResponse? = null,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.offazure.outputs.GetSitesControllerResult):
            GetSitesControllerResult = GetSitesControllerResult(
            agentDetails = javaType.agentDetails().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.offazure.kotlin.outputs.SiteAgentPropertiesResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            applianceName = javaType.applianceName().map({ args0 -> args0 }).orElse(null),
            discoverySolutionId = javaType.discoverySolutionId().map({ args0 -> args0 }).orElse(null),
            eTag = javaType.eTag(),
            id = javaType.id(),
            location = javaType.location(),
            masterSiteId = javaType.masterSiteId(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            serviceEndpoint = javaType.serviceEndpoint(),
            servicePrincipalIdentityDetails = javaType.servicePrincipalIdentityDetails().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.offazure.kotlin.outputs.SiteSpnPropertiesResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.offazure.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/offazure/kotlin/outputs/GetSitesControllerResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.offazure.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * A VmwareSite
 * @property agentDetails Gets or sets the on-premises agent details.
 * @property applianceName Gets or sets the Appliance Name.
 * @property discoverySolutionId Gets or sets the ARM ID of migration hub solution for SDS.
 * @property eTag If eTag is provided in the response body, it may also be provided as a header per the normal etag convention.  Entity tags are used for comparing two or more entities from the same requested resource. HTTP/1.1 uses entity tags in the etag (section 14.19), If-Match (section 14.24), If-None-Match (section 14.26), and If-Range (section 14.27) header fields.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property location The geo-location where the resource lives
 * @property masterSiteId Gets the Master Site this site is linked to.
 * @property name The name of the resource
 * @property provisioningState The status of the last operation.
 * @property serviceEndpoint Gets the service endpoint.
 * @property servicePrincipalIdentityDetails Gets or sets the service principal identity details used by agent for
 * communication
 *             to the service.
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property tags Resource tags.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetSitesControllerResult(
    public val agentDetails: SiteAgentPropertiesResponse? = null,
    public val applianceName: String? = null,
    public val discoverySolutionId: String? = null,
    public val eTag: String,
    public val id: String,
    public val location: String,
    public val masterSiteId: String,
    public val name: String,
    public val provisioningState: String,
    public val serviceEndpoint: String,
    public val servicePrincipalIdentityDetails: SiteSpnPropertiesResponse? = null,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.offazure.outputs.GetSitesControllerResult): GetSitesControllerResult = GetSitesControllerResult(
            agentDetails = javaType.agentDetails().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.offazure.kotlin.outputs.SiteAgentPropertiesResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            applianceName = javaType.applianceName().map({ args0 -> args0 }).orElse(null),
            discoverySolutionId = javaType.discoverySolutionId().map({ args0 -> args0 }).orElse(null),
            eTag = javaType.eTag(),
            id = javaType.id(),
            location = javaType.location(),
            masterSiteId = javaType.masterSiteId(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            serviceEndpoint = javaType.serviceEndpoint(),
            servicePrincipalIdentityDetails = javaType.servicePrincipalIdentityDetails().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.offazure.kotlin.outputs.SiteSpnPropertiesResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.offazure.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
        )
    }
}
